PCB Environment: RatsNest Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
RatsNest Class Reference

## Public Member Functions
| RatsNest (const PCBoard &)
void | setHL (const std::vector< Connection * > *)
void | update ()
void | updateHL ()
void | draw (const Camera &)
void | setLineWidth (float w)
float | getLayerAlpha (uint z) const
void | setLayerAlpha (uint z, float a)
void | setColorHL (Color c)
bool | allVisible () const
void | setAllVisible (bool b)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/RatsNest.hpp